@@ -11,7 +11,7 @@
 */
 
 /*
- * $Id: environ.c 8 2008-05-28 09:27:26Z rmanfredi $
+ * $Id: environ.c 58 2008-08-19 08:44:07Z rmanfredi $
  *
  *  Copyright (c) 1990-2006, Raphael Manfredi
  *  
@@ -46,11 +46,15 @@
 #else
 #include <strings.h>
 #endif
+#ifdef I_STDLIB
+#include <stdlib.h>
+#else
 #ifdef I_MALLOC
 #include <malloc.h>
 #else
 extern char *malloc();				/* Memory allocation */
 #endif
+#endif	/* I_STDLIB */
 #include "confmagic.h"
 
 #define ENV_VARS	200				/* An average number of environment vars */
