@@ -11,7 +11,7 @@
 */
 
 /*
- * $Id: io.c 8 2008-05-28 09:27:26Z rmanfredi $
+ * $Id: io.c 58 2008-08-19 08:44:07Z rmanfredi $
  *
  *  Copyright (c) 1990-2006, Raphael Manfredi
  *  
@@ -105,11 +105,15 @@
 #include <unistd.h>		/* R_OK and friends */
 #endif
 
+#ifdef I_STDLIB
+#include <stdlib.h>
+#else
 #ifdef I_MALLOC
 #include <malloc.h>
 #else
-extern char *malloc();
+extern char *malloc();				/* Memory allocation */
 #endif
+#endif	/* I_STDLIB */
 
 #ifdef I_SYS_WAIT
 #include <sys/wait.h>
