@@ -1,4 +1,4 @@
-;# $Id: matching.pl 3 2008-01-17 09:58:33Z rmanfredi $
+;# $Id: matching.pl 38 2008-06-13 09:32:24Z rmanfredi $
 ;#
 ;#  Copyright (c) 1990-2006, Raphael Manfredi
 ;#  
@@ -80,15 +80,11 @@ sub perl_pattern {
 }
 
 # Take a pattern as written in the rule file and make it suitable for
-# pattern matching as understood by perl. If the pattern starts with a
-# leading /, nothing is done. Otherwise, a set of / are added.
-# match (1st case).
+# pattern matching as understood by perl. Unless the pattern starts with a
+# leading / or is of the form m||, it is enclosed within slashes.
+# We also enclose the whole pattern within ().
 sub make_pattern {
 	local($_) = shift(@_);
-	unless (m|^/|) {				# Pattern does not start with a /
-		$_ = &perl_pattern($_);		# Simple words specified via shell patterns
-		$_ = "/^$_\$/";				# Anchor pattern
-	}
 	# The whole pattern is inserted within () to make at least one
 	# backreference. Otherwise, the following could happen:
 	#    $_ = '1 for you';
@@ -98,7 +94,15 @@ sub make_pattern {
 	# determine whether it is due to a backreference (2nd case) or a sucessful
 	# match. Knowing we have at least one bracketed reference is enough to
 	# disambiguate.
-	s|^/(.*)/|/($1)/|;		# Enclose whole pattern within ()
+	if (/^m(\W)(.*)\1(\w*)$/) {
+		$_ = "m$1($2)$1$3";
+	} elsif (m|^/(.*)/(\w*)$|) {
+		$_ = "/($1)/$2";
+	} else {
+		# Pattern does not start with a / or is not of the form m|xxx|
+		$_ = &perl_pattern($_);		# Simple words specified via shell patterns
+		$_ = "/^($_)\$/";			# Anchor pattern
+	}
 	$_;						# Pattern suitable for eval'ed matching
 }
 
@@ -344,31 +348,33 @@ sub match_list {
 sub match_var {
 	local($selector, $pattern, $range) = @_;
 	local($lines) = 0;					# Number of lines in matching buffer
+	my $target = \$Header{$selector};
+	# Need to special-case Body to use the *decoded* version
+	$target = $Header{'=Body='} if $selector eq 'Body';
 	if ($range ne '<1,->') {			# Optimize: count lines only if needed
-		$lines = $Header{$selector} =~ tr/\n/\n/;
+		$lines = $$target =~ tr/\n/\n/;
 	}
 	local($min, $max) = &mrange($range, $lines);
 	return 0 unless $min;				# No matching possible if null range
-	local($buffer);						# Buffer on which matching is attempted
+	my $buffer;							# Buffer on which matching is attempted
 	local(@buffer);						# Same, whith range line selected
 	local(@matched);
 	$pattern = &make_pattern($pattern);
 	# Optimize, since range selection is the exception and not the rule.
 	# Most likely, we use the default selection, i.e. we take everything...
 	if ($min != 1 || $max != 9_999_999) {
-		@buffer = split(/\n/, $Header{$selector});
+		@buffer = split(/\n/, $$target);
 		@buffer = @buffer[$min - 1 .. ($max > $#buffer ? $#buffer : $max - 1)];
 		$buffer = join("\n", @buffer);		# Keep only selected lines
 		undef @buffer;						# May be big, so free ASAP
-	} else {
-		$buffer = $Header{$selector};
+		$target = \$buffer;
 	}
 	# Ensure multi-line matching by adding trailing "m" option to pattern
-	@matched = eval '($buffer =~ ' . $pattern . 'm);';
+	@matched = eval '($$target =~ ' . $pattern . 'm);';
 	# If buffer is empty, we have to recheck the pattern in a non array context
 	# to see if there is a match. Otherwise, /(.*)/ does not seem to match an
 	# empty string as it returns an empty string in $matched[0]...
-	$matched[0] = eval '$buffer =~ ' . $pattern . 'm' if $buffer eq '';
+	$matched[0] = eval '$$target =~ ' . $pattern . 'm' unless length $$target;
 	&eval_error;						# Make sure eval worked
 	&update_backref(*matched);			# Record non-null backreferences
 	$matched[0];						# Return matching status
