@@ -1,6 +1,6 @@
-;# $Id: q.pl,v 3.0 1993/11/29 13:49:10 ram Exp $
+;# $Id: q.pl 3 2008-01-17 09:58:33Z rmanfredi $
 ;#
-;#  Copyright (c) 1990-1993, Raphael Manfredi
+;#  Copyright (c) 1990-2006, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic License,
 ;#  as specified in the README file that comes with the distribution.
@@ -9,14 +9,13 @@
 ;#  of the source tree for mailagent 3.0.
 ;#
 ;# $Log: q.pl,v $
-;# Revision 3.0  1993/11/29 13:49:10  ram
+;# Revision 3.0  1993/11/29  13:49:10  ram
 ;# Baseline for mailagent 3.0 netwide release.
 ;#
 # Quotation removal routine
 sub q {
 	local($_) = @_;
-	local($*) = 1;
-	s/^://g;
+	s/^://gm;
 	$_;
 }
 
